@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import os
+from collections import OrderedDict
 from typing import TYPE_CHECKING, Sequence
 
 from jinja2 import pass_context
@@ -23,8 +24,11 @@ def format_action_signature(context: Context, id: str, repo: str, options: GitHu
     match options.signature_version:
         case "ref":
             try:
-                repo: Repo = context.environment.globals["git_repo"]
-                version = repo.head.ref.name
+                git_repo = context.environment.globals["git_repo"]
+                if isinstance(git_repo, Repo):
+                    version = git_repo.head.ref.name
+                else:
+                    version = "unknown"
             except Exception:
                 version = "unknown"
         case "major":
@@ -37,6 +41,22 @@ def format_action_signature(context: Context, id: str, repo: str, options: GitHu
     return f"{name}@{version}"
 
 
+def group_parameters(
+    parameters: Sequence[Input | Output | Secret],
+    do_group: bool,
+) -> OrderedDict[str, list[Input | Output | Secret]]:
+    grouped: OrderedDict[str, list[Input | Output | Secret]] = OrderedDict()
+    if not do_group:
+        grouped[""] = list(parameters)
+        return grouped
+    for parameter in parameters:
+        group = getattr(parameter, "group", "")
+        if group not in grouped:
+            grouped[group] = []
+        grouped[group].append(parameter)
+    return grouped
+
+
 def order_parameters(
     parameters: Sequence[Input | Output | Secret], parameters_order: PARAMETERS_ORDER
 ):
